# Mable DSO Tool CLI
This tool assists DevSecOps engineers to perform the following tasks:
- Configuration management
    - Paramaters
    - Secrets
    - Templates
- Package management
- Release management
- Provision resources
- Deploy releases
- Security testing (SAST/DAST)


To find out more please visit the [homepage](https://github.com/bettercaring/mabledsocli) of the project. 
